<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Request\Filter;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\HTTP\Kernel;
use Teknisa\MAN\Services;
use Teknisa\MAN\Utilities;

class ParamsKDS extends \Zeedhi\Framework\Controller\Simple {
    protected $setorService;
    protected $salesMessage;
    protected $util;
    protected $produtoService;
    protected $ocorrenciaService;
    protected $fileService;
    public function __construct(Services\Setor $setorService, Utilities\SalesMessage $salesMessage, Utilities\Util $util,
                                 Services\Produto $produtoService, Services\Ocorrencia $ocorrenciaService,
                                  Services\File $fileService) {
        $this->setorService      = $setorService;
        $this->salesMessage      = $salesMessage;
        $this->util              = $util;
        $this->produtoService    = $produtoService;
        $this->ocorrenciaService = $ocorrenciaService;
        $this->fileService = $fileService;                        
    }
    
    //Setor
    public function buscaSetores(Filter $request, Response $response) {
        try {

            $setores = $this->setorService->buscaSetores();
            $setores = self::trataTipoSetor($setores);
            // $response->addDataSet(new DataSet('BuscaSetoresRepo', $setores));
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('BuscaSetoresRepo', $setores));

        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    private function trataTipoSetor($setores){
        //poderia ter passado ponteiro de setor mas ia ficar muito dificil de notar
        for ($cont = 0 ; $cont < count($setores); $cont++) {
            switch ($setores[$cont]['IDTIPOSETOR']) {
                case 'P':
                    $setores[$cont]['NMTIPOSETOR'] = "Produção";
                    break;
                case 'E':
                    $setores[$cont]['NMTIPOSETOR'] = "Expedição";
                    break;
                case 'M':
                    $setores[$cont]['NMTIPOSETOR'] = "Montagem";
            }
            if(!empty($setores[$cont]["NMARQUIVO"])){
                $setores[$cont]["SOMBEEP"] = array(
                    array(
                        'b64File' => $setores[$cont]["ARQUIVO"],
                        'name' => $setores[$cont]["NMARQUIVO"],
                        'size' => '1',
                        'type' => $setores[$cont]["TPARQUIVO"]
                    )
                );
            }
        }
        return $setores;
    }
 
    public function editaSetor(Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);

            $SGSETOR = $params['SGSETOR'];
            $NMSETOR = $params['NMSETOR'];
            $IDTIPOSETOR = $params['IDTIPOSETOR'];
            $CDSETOR = strchr($params['CDSETOR'],'#altera', true);
            $NOVOCDSETOR = $params['NOVOCDSETOR'];
            $message = array('Editado com sucesso!');
            if($CDSETOR == false){
                $CDSETOR = $params['NOVOCDSETOR'];
                $validaNovo = $this->setorService->validaSetor($SGSETOR, $NMSETOR, $IDTIPOSETOR, $CDSETOR);

                if(count($validaNovo)!=0){
                    throw new \Exception($this->salesMessage->getMessage(81).$validaNovo[0]["CDSETOR"].".");
                }

                $this->setorService->criaSetor($CDSETOR, $SGSETOR, $NMSETOR, $IDTIPOSETOR);
                $message = array('message' => $this->salesMessage->getMessage("criado") );
            }else{
                $produtos = $this->setorService->buscaProdutosSetorEspecifico($CDSETOR);
                
                foreach ($produtos as $produto) {
                    $isSetorFilial = $this->setorService->buscaSetorFilialPorCDSETOR($CDSETOR);
                    $validaVazio = $this->setorService->buscaSetorProdutoPorCDSETOR($CDSETOR);
                    if(!empty($isSetorFilial)){
                        if (!empty($validaVazio)){
                            $this->setorService->alteraCDSETORSetorProduto($CDSETOR, $NOVOCDSETOR, $produto['CDPRODUTO']);
                            $this->setorService->alteraCDSETORSetorFilial($CDSETOR, $NOVOCDSETOR);
                            $message = array('message' => $this->salesMessage->getMessage("alterado"));
                        }else{
                            $this->setorService->alteraCDSETORSetorFilial($CDSETOR, $NOVOCDSETOR);
                            $message = array('message' => $this->salesMessage->getMessage("alterado"));
                        }
                    }else if(!empty($validaVazio)){
                        $this->setorService->alteraCDSETORSetorProduto($CDSETOR, $NOVOCDSETOR, $produto['CDPRODUTO']);
                        $message = array('message' => $this->salesMessage->getMessage("alterado"));
                    }
                }
                    $answer =$this->setorService->alteraSetor($CDSETOR, $NOVOCDSETOR, $SGSETOR, $NMSETOR, $IDTIPOSETOR);
            }

            /* Force message to be an array */
            //$message = array($message);
            
            $setores = $this->setorService->buscaSetores();
            $setores = self::trataTipoSetor($setores);
            $response->addDataSet(new DataSet('BuscaSetoresRepo', $setores));
            $response->addDataSet(new DataSet('EditaSetorSetorRepo', $message));

        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
    
    public function excluiSetor(Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);

            $validaVazio = $this->setorService->buscaProdutosSetorEspecifico($params['CDSETOR']);
            if (count($validaVazio)==0){
                $this->setorService->excluiSetor($params['CDSETOR']);
                $message = array('message' => $this->salesMessage->getMessage("excluido"));
            }else if($params['PRODUTOS']== "tem"){
                $this->setorService->excluiProdutosSetor($params['CDSETOR']);
                $this->setorService->excluiSetor($params['CDSETOR']);
                $message = array('message' => $this->salesMessage->getMessage("excluido"));
            }else{
                $message = array('message' => "temproduto" );
            }
            $setores = $this->setorService->buscaSetores();
            $setores = self::trataTipoSetor($setores);
            $response->addDataSet(new DataSet('BuscaSetoresRepo', $setores));
            $response->addDataSet(new DataSet('ExcluiSetorRepo', $message));
        }catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function excluiSetorLoja(Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $this->setorService->excluiSetorLoja($params['CDSETOR'], $params['CDLOJA']);
            $setores = $this->setorService->buscaSetores();
            $setores = self::trataTipoSetor($setores);
            $message = array('message' => $this->salesMessage->getMessage("excluido"));
            $response->addDataSet(new DataSet('BuscaSetoresRepo', $setores));
            $response->addDataSet(new DataSet('ExcluiSetorLoja', $message));
        }catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    //Produto
    public function buscaProdutosSetor (Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $CDSETOR = $params['CDSETOR'];
            $produtos = $this->buscaProdutosSetorEspecifico($CDSETOR);
            $response->addDataSet(new DataSet('BuscaProdutosSetorRepo', $produtos));

        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
    private function buscaProdutosSetorEspecifico($CDSETOR){
        $produtos = $this->setorService->buscaProdutosSetorEspecifico($CDSETOR);
        foreach ($produtos as &$produto) {
            $produto['NRTEMPOPROD'] = self::secondsToTime((int)$produto['NRTEMPOPROD']);
            if(!empty($produto['NRTEMPOEXIB'])){
                $produto['NRTEMPOEXIB'] = self::secondsToTime((int)$produto['NRTEMPOEXIB']);
            }
        }
        return $produtos;
    }

    //pega um tempo em segundos e passa para um tempo ii:ss
    //str_pad(numero, tamanho, filler, STR_PAD_LEFT(funçao, essa enche pra esquerda));
    private function secondsToTime($time) {
        if (($time / 60) >= 1) {
            $minutes = str_pad((string)(intval($time / 60)), 2, '0', STR_PAD_LEFT);
        } else {
            $minutes = '00';
        }
        $seconds = str_pad((string)(intval($time % 60)), 2, '0', STR_PAD_LEFT);

        return $minutes . ':' . $seconds;
    }

    public function buscaObservacaoProduto (Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);

            if(empty($params['CDPRODUTO'])){
                $params['CDPRODUTO'] = "%%";
            }
            $observacoes = $this->produtoService->buscaObservacaoProduto($params['CDPRODUTO']);

            $response->addDataSet(new DataSet('BuscaObservacaoProdutoRepo', $observacoes));

        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function editaProdutoSetor(Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);

            $CDSETOR = $params['CDSETOR'];
            $NRTEMPOPROD = $params['NRTEMPOPROD'];
            $CDPRODUTO = $params['CDPRODUTO'];
            $NRTEMPOEXIB = null;
            if (!empty($params['NRTEMPOEXIB'])&&(!$params['NRTEMPOEXIB']== '')){
                $NRTEMPOEXIB = $params['NRTEMPOEXIB'];
            }

            $this->setorService->alteraProdutoSetor($CDSETOR, $CDPRODUTO, $NRTEMPOPROD, $NRTEMPOEXIB);
            $message = array('message' => $this->salesMessage->getMessage("alterado"));

            $produtos = $this->buscaProdutosSetorEspecifico($CDSETOR);

            $response->addDataSet(new DataSet('BuscaProdutosSetorRepo', $produtos));
            $response->addDataSet(new DataSet('EditaProdutoSetorRepo', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function editaProdutoSetores(Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);

            $NRTEMPOPROD = $params['NRTEMPOPROD'];
            $CDPRODUTO = $params['CDPRODUTO'];
            $NRTEMPOEXIB = null;
            if (!empty($params['NRTEMPOEXIB'])&&(!$params['NRTEMPOEXIB']== '')){
                $NRTEMPOEXIB = $params['NRTEMPOEXIB'];
            }

            $this->setorService->alteraProdutoSetores($CDPRODUTO, $NRTEMPOPROD, $NRTEMPOEXIB);
            $message = array('message' => $this->salesMessage->getMessage("alterado"));

            $response->addDataSet(new DataSet('EditaProdutoSetoresRepo', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function adicionaProdutoSetor(Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);

            $CDSETOR = $params['CDSETOR'];
            $NRTEMPOPROD = $params['NRTEMPOPROD'];
            $CDPRODUTO = $params['CDPRODUTO'];
            $NRTEMPOEXIB = null;
            if (!empty($params['NRTEMPOEXIB'])&&(!$params['NRTEMPOEXIB']== '')){
                $NRTEMPOEXIB = $params['NRTEMPOEXIB'];
            }

            $this->setorService->criaProdutoSetor($CDSETOR, $CDPRODUTO, $NRTEMPOPROD, $NRTEMPOEXIB);
            $message = array('message' => $this->salesMessage->getMessage("alterado"));

            $produtos = $this->buscaProdutosSetorEspecifico($CDSETOR);

            $response->addDataSet(new DataSet('BuscaProdutosSetorRepo', $produtos));
            $response->addDataSet(new DataSet('EditaProdutoSetorRepo', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function editRangeProdSetor(Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);

            $CDSETOR = $params['CDSETOR'];
            $NRTEMPOPROD = $params['NRTEMPOPROD'];
            $CDPRODUTO = $params['CDPRODUTO'];     //testa se é alteração e se for já pega o codigo do Produto
            $CDPRODUTO2 = $params['CDPRODUTO2'];   //testa se é alteração e se for já pega o codigo do Produto
            $NRTEMPOEXIB = null;
            if (!empty($params['NRTEMPOEXIB'])&&(!$params['NRTEMPOEXIB']== '')){
                $NRTEMPOEXIB = $params['NRTEMPOEXIB'];
            }

            $CDARVPROD  = $this->produtoService->buscaCDARVPROD($CDPRODUTO);
            $CDARVPROD  = $CDARVPROD[0]['CDARVPROD'];
            $CDARVPROD2 = $this->produtoService->buscaCDARVPROD($CDPRODUTO2);
            $CDARVPROD2 = $CDARVPROD2[0]['CDARVPROD'];
            if ($CDARVPROD2 < $CDARVPROD){
                $temp = $CDARVPROD;
                $CDARVPROD = $CDARVPROD2;
                $CDARVPROD2 = $temp;
            }
            $produtosRange = $this->produtoService->buscaProdutosRange($CDARVPROD, $CDARVPROD2);
            for($i = 0; $i < count($produtosRange); $i++) {
                $cdProdInclusao = $produtosRange[$i]['CDPRODUTO'];
                $validProduct = self::validaProdutoExisteSetor($cdProdInclusao, $CDSETOR);

                if ($validProduct['ok']) {
                    $NRORG = '1';
                    $this->setorService->criaProdutoSetor($CDSETOR, $cdProdInclusao, $NRTEMPOPROD, $NRTEMPOEXIB);
                    $message = array('message' => $this->salesMessage->getMessage("criado"));
                } else {
                    $this->setorService->alteraProdutoSetor($CDSETOR, $cdProdInclusao, $NRTEMPOPROD, $NRTEMPOEXIB);
                    $message = array('message' => $this->salesMessage->getMessage("alterado"));
                }
            }
            $produtos = $this->buscaProdutosSetorEspecifico($CDSETOR);
            $response->addDataSet(new DataSet('BuscaProdutosSetorRepo', $produtos));
            $response->addDataSet(new DataSet('EditaProdutoSetorRepo', $message));

        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function validaProdutoExisteSetor($CDPRODUTO, $CDSETOR){
        $result = array();
        $validaNovo = $this->setorService->validaProduto($CDPRODUTO, $CDSETOR);
        if(count($validaNovo) != 0){
            $result['ok'] = false;
        } else {
            $result['ok'] = true;
        }
        return $result;
    }

    public function excluiProdutoSetor(Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $produto = json_decode($params['produto'], true);

            $observacoes = $this->ocorrenciaService->buscaObservacaoProdutoSetor($produto['CDPRODUTO'], $produto['CDSETOR']);

            if (empty($observacoes)) {
                $this->setorService->excluiProdutoSetor($produto['CDPRODUTO'], $produto['CDSETOR']);
                $message = array('message' => $this->salesMessage->getMessage("excluido"));
                $produto = $this->buscaProdutosSetorEspecifico($produto['CDSETOR']);

                $response->addDataSet(new DataSet('BuscaProdutosSetorRepo', $produto));
                $response->addDataSet(new DataSet('ExcluiProdutoSetorRepo', $message));
            } else {
                $message = array('message' => $this->salesMessage->getMessage(100));
                $response->addDataSet(new DataSet('ExcluiProdutoSetorRepo', $message));
            }
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
   
    //Intervalo
    public function buscaProdutoIntervalo (Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $CDSETOR = $params['CDSETOR'];
            $CDPRODUTO = $params['CDPRODUTO'];
            $intervalos = $this->setorService->buscaProdutoIntervalo($CDSETOR, $CDPRODUTO);
            $response->addDataSet(new DataSet('BuscaProdutoIntervalosRepo', $intervalos));

        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function editaProdutoIntervalo(Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);

            $CDSETOR = $params['CDSETOR'];
            $CDPRODUTO = $params['CDPRODUTO'];
            $NRTEMPOINTER = $params['NRTEMPOINTER'];
            $NRSEQINTERVALO = $params['NRSEQINTERVALO'];

            // if it's a new interval
            if($NRSEQINTERVALO == 'cria'){
                $NRSEQINTERVALO = $this->util->newCode('SETORPRODINTER' . $CDSETOR . $CDPRODUTO, '10');
                $validaNovo =  $this->setorService->buscaProdutoIntervalo($CDSETOR, $CDPRODUTO, $NRTEMPOINTER);;
                if(count($validaNovo)!=0){
                    throw new \Exception($this->salesMessage->getMessage(109));
                }
                $this->setorService->criaProdutoIntervalo($CDSETOR, $CDPRODUTO, $NRSEQINTERVALO, $NRTEMPOINTER);
                $message = array('message' => $this->salesMessage->getMessage("criado") );

            // if it's editing an existent interval               
            } else {
                $this->setorService->alteraProdutoIntervalo($CDSETOR, $CDPRODUTO, $NRSEQINTERVALO, $NRTEMPOINTER);
                $message = array('message' => $this->salesMessage->getMessage("alterado") );
            }

            $intervalos = $this->setorService->buscaProdutoIntervalo($CDSETOR, $CDPRODUTO);
            $response->addDataSet(new DataSet('BuscaProdutoIntervalosRepo', $intervalos));
            $response->addDataSet(new DataSet('EditaProdutoIntervalosRepo', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function excluiProdutoIntervalo(Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $CDSETOR = $params['CDSETOR'];
            $CDPRODUTO = $params['CDPRODUTO'];
            $NRSEQINTERVALO = $params['NRSEQINTERVALO'];
            $this->setorService->excluiProdutoIntervalo($CDPRODUTO, $CDSETOR, $NRSEQINTERVALO);
            $message = array('message' => $this->salesMessage->getMessage("excluido"));
            $intervalos = $this->setorService->buscaProdutoIntervalo($CDSETOR, $CDPRODUTO);
            $response->addDataSet(new DataSet('BuscaProdutoIntervalosRepo', $intervalos));
            $response->addDataSet(new DataSet('ExcluiProdutoIntervalosRepo', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    //Filial
    public function buscaSetorFilial(Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $setores = $this->setorService->buscaSetorFilial($params['CDFILIAL']);
            $setores = self::trataTipoSetor($setores);
            $response->addDataSet(new DataSet('BuscaSetorFilial', $setores));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function editaSetorFilial(Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);

            $CDSETOR = $params['CDSETOR'];
            // testa se é alteração e se for já pega o codigo do produto
            $CDFILIAL = strchr($params['CDFILIAL'],'#altera', true);
            $IDHABROLLBKDS = $params['IDHABROLLBKDS'];
            $IDHABSOMKDS = $params['IDHABSOMKDS'];
            $NRPRODATRAINISOM = $params['NRPRODATRAINISOM'];
            $IDHABTIMERPROD = $params['IDHABTIMERPROD'];
            $IDHABSOMPROD = $params['IDHABSOMPROD'];
            $IDHABCONTSOMPROD = $params['IDHABCONTSOMPROD'];
            $IDBLOQPRODKDS = $params['IDBLOQPRODKDS'];
            $NRROLLBTIME = empty($params['NRROLLBTIME'])? null : $params['NRROLLBTIME'];
            $IDCONTSOMKDS = $params['IDCONTSOMKDS'];
            $IDHABPREENVIO = $params['IDHABPREENVIO'];
            $TEMPOBEEP = empty($params['TEMPOBEEP'])? null : $params['TEMPOBEEP'];
            $IDSOMBEEP = $params['IDSOMBEEP'];
            $IDCONCDIRETO = $params['IDCONCDIRETO'];


            if ($CDFILIAL == false) {
                $CDFILIAL = $params['CDFILIAL'];
                // verifica se o produto já está em algum setor do mesmo tipo para esta filial
                $valSetorFilial = $this->setorService->validaSetorFilial($CDSETOR, $CDFILIAL);
                if (empty($valSetorFilial)) {
                    $valSetorProduto = $this->setorService->validaSetorProduto($CDSETOR, $CDFILIAL);
                    if (count($valSetorProduto) == 0) {
                        $this->setorService->criaSetorFilial($CDSETOR, $CDFILIAL, $IDHABSOMKDS, $IDHABROLLBKDS,
                                                             $IDHABTIMERPROD, $IDHABSOMPROD, $IDHABCONTSOMPROD, $IDBLOQPRODKDS,
                                                             $NRROLLBTIME, $IDCONTSOMKDS, $IDHABPREENVIO, $TEMPOBEEP, $NRPRODATRAINISOM, 
                                                             $IDSOMBEEP, $IDCONCDIRETO);
                        $message = array('message' => $this->salesMessage->getMessage("criado"));
                    } else{
                        throw new \Exception($this->salesMessage->getMessage(91) . ' ' . $valSetorProduto[0]['LABEL']);
                    }
                } else {
                    throw new \Exception($this->salesMessage->getMessage(82));
                }
            } else {
                $this->setorService->alteraSetorFilial($CDSETOR, $CDFILIAL, $IDHABSOMKDS, $IDHABROLLBKDS,
                                                       $IDHABTIMERPROD, $IDHABSOMPROD, $IDHABCONTSOMPROD, $IDBLOQPRODKDS,
                                                       $NRROLLBTIME, $IDCONTSOMKDS, $IDHABPREENVIO, $TEMPOBEEP, $NRPRODATRAINISOM, 
                                                       $IDSOMBEEP, $IDCONCDIRETO);
                $message = array('message' => $this->salesMessage->getMessage("alterado"));
            }
            $setores = $this->setorService->buscaSetorFilial($CDFILIAL);
            $setores = self::trataTipoSetor($setores);

            $response->addDataSet(new DataSet('BuscaSetorFilial', $setores));
            $response->addDataSet(new DataSet('EditaSetorFilial', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
    
    public function uploadAudio (Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $SOMBEEP = $params['SOMBEEP'];
            
            $CODE = $this->util->newCode('FILETABLE', '20');
            $this->fileService->saveFile($CODE, $SOMBEEP[0]['name'], $SOMBEEP[0]['b64File'], $SOMBEEP[0]['type']);


            $response->addDataSet(new DataSet('UploadAudioRepo', [$CODE]));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
    
    public function getAudios (Filter $request, Response $response) {
        try {
            //this is a little bit of "baixaria das boas"
            $beeps = $this->fileService->getFiles('','','', 'Audio');
            $response->addDataSet(new DataSet('UploadAudioRepo', $beeps));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }


    public function excluiAudios(Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);


            //validabeeps will have a return from a query that searchs setorfilial whit that song
            if (empty($validaBeeps)){
                $beeps = json_decode($params['beeps'], true);

                foreach ($beeps as $beep) {
                    $this->fileService->deleteFile($beep['CDARQUIVO']);
                }

                $beeps = $this->fileService->getFiles('','','', 'Audio');
                $response->addDataSet(new DataSet('UploadAudioRepo', $beeps));
                $message = array('message' => $this->salesMessage->getMessage("excluido"));
                $response->addDataSet(new DataSet('DeleteSelectedBeepsRepo', $message));
            }else{
                //wow Hilston we have a problem, are u sure tha I have o delete this user?
                //if yes...
                if($params['areUSureAboutThis']){
                    foreach ($beeps as $beep) {
                        $this->fileService->deleteFile($beep['CDARQUIVO']);
                    }

                    $beeps = $this->fileService->getFiles('','','', 'Audio');
                    $response->addDataSet(new DataSet('UploadAudioRepo', $beeps));
                    $message = array('message' => $this->salesMessage->getMessage("excluido"));
                    $response->addDataSet(new DataSet('DeleteSelectedBeepsRepo', $message));
                }else{
                    $message = array('message' => "Existe(m) setore(s) associado(s) a este beep. Tem certeza que quer deleta-lo?");
                    $response->addDataSet(new DataSet('DeleteSelectedBeepsRepo', $message));
                }
            }

        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
    
    public function validaProdutoExisteSetorFilial($CDPRODUTO, $CDSETOR, $CDFILIAL){
        $result = array();
        $validaNovo = $this->setorService->validaProdutoFilial($CDPRODUTO, $CDFILIAL);
        if(count($validaNovo) != 0){
            $tipoSetor = $this->setorService->buscaTipoSetor($CDSETOR);
            $tipoSetor = $tipoSetor[0];
            foreach ($validaNovo as $setorAtual) {
                if ($tipoSetor['IDTIPOSETOR'] != $setorAtual['IDTIPOSETOR']) {
                    $result['ok'] = true;
                } else {
                    $result['ok'] = false;
                }
            }
        } else {
            $result['ok'] = true;
        }
        return $result;
    }

    public function excluiSetorFilial(Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $setores = json_decode($params['setores'], true);
            foreach ($setores as $setor) {
                $this->setorService->excluiSetorFilial($setor['CDSETOR'], $setor['CDFILIAL']);
            }
            $message = array('message' => $this->salesMessage->getMessage("excluido"));
            $setores = $this->setorService->buscaSetorFilial($setores[0]['CDFILIAL']);
            $setores = self::trataTipoSetor($setores);
            $response->addDataSet(new DataSet('BuscaSetorFilial', $setores));
            $response->addDataSet(new DataSet('ExcluiSetorFilial', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function excluiSetorFilialChecked (Filter $request, Response $response){
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $setores = json_decode($params['setores'], true);
            foreach ($setores as $setor) {
                $this->setorService->excluiSetor($setor['CDSETOR']);
            }
            $message = array('message' => $this->salesMessage->getMessage("excluido"));
            $response->addDataSet(new DataSet('ExcluiSetorFilial', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function getAtrasoPadrao (Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $CDFILIAL = $params[0]['value'];
            $retorno = $this->setorService->getAtrasoPadrao($CDFILIAL);
            $response->addDataSet(new DataSet('AtrasoPadraoRepository', $retorno));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function editAtrasoPadrao (Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $NRATRAPADRAO = $params['NRATRAPADRAO'];
            $CDFILIAL = $params['CDFILIAL'];
            $this->setorService->editAtrasoPadrao($CDFILIAL, $NRATRAPADRAO);
            $message = array('message' => $this->salesMessage->getMessage("alterado"));
            $response->addDataSet(new DataSet('EditAtrasoPadraoRepo', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    //Cores
    public function buscaCoresPedido(Filter $request, Response $response) {
        try {
            $cores = $this->setorService->buscaCoresPedido();
            for ($cont = 0 ; $cont < count($cores); $cont++) {
                switch ($cores[$cont]['IDPISCAPED']) {
                    case 'S':
                        $cores[$cont]['DSPISCAPED'] = "Sim";
                        break;
                    case 'N':
                        $cores[$cont]['DSPISCAPED'] = "Não";
                        break;
                }
            }
            $response->addDataSet(new DataSet('BuscaCoresPedidoRepo', $cores));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function buscaCorPedido(Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $NRSEQCORPEDIDO  = $params['NRSEQCORPEDIDO'];
            $cores = $this->setorService->buscaCorPedido($NRSEQCORPEDIDO);
            for ($cont = 0 ; $cont < count($cores); $cont++) {
                switch ($cores[$cont]['IDPISCAPED']) {
                    case 'S':
                        $cores[$cont]['DSPISCAPED'] = "Sim";
                        break;
                    case 'N':
                        $cores[$cont]['DSPISCAPED'] = "Não";
                        break;
                }
            }
            $response->addDataSet(new DataSet('BuscaCorPedidoRepo', $cores));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
    
    public function editaCor(Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $NRINICIOCOR = $params['NRINICIOCOR'];
            $NRFINALCOR = $params['NRFINALCOR'];
            $NRCORPEDIDO = $params['NRCORPEDIDO'];
            $IDPISCAPED = $params['IDPISCAPED'];
            $NRSEQCORPEDIDO = $params['NRSEQCORPEDIDO'];
            $valida = $this->setorService->validaCor($NRINICIOCOR, $NRFINALCOR, $NRSEQCORPEDIDO);
            if (count($valida) != 0) {
                throw new \Exception($this->salesMessage->getMessage(31));
            }
            if($NRSEQCORPEDIDO == 'cria'){
                $NRSEQCORPEDIDO = $this->util->newCode('CORPEDIDO', '50');
                $this->setorService->criaCor($NRINICIOCOR, $NRFINALCOR, $IDPISCAPED, $NRCORPEDIDO, $NRSEQCORPEDIDO);
                $message = array('message' => $this->salesMessage->getMessage("criado"));
            }else{
                $this->setorService->alteraCor($NRINICIOCOR, $NRFINALCOR, $IDPISCAPED, $NRCORPEDIDO, $NRSEQCORPEDIDO);
                $message = array('message' => $this->salesMessage->getMessage("alterado"));
            }
            $cores = $this->setorService->buscaCoresPedido();
            for ($cont = 0 ; $cont < count($cores); $cont++) {
                switch ($cores[$cont]['IDPISCAPED']) {
                    case 'S':
                        $cores[$cont]['DSPISCAPED'] = "Sim";
                        break;
                    case 'N':
                        $cores[$cont]['DSPISCAPED'] = "Não";
                        break;
                }
            }
            $response->addDataSet(new DataSet('BuscaCoresPedidoRepo', $cores));
            $response->addDataSet(new DataSet('EditaCorRepo', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
    
    public function alteracor(Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $NRINICIOCOR = $params['NRINICIOCOR'];
            $NRFINALCOR = $params['NRFINALCOR'];
            $NRCORPEDIDO = $params['NRCORPEDIDO'];
            $IDPISCAPED = $params['IDPISCAPED'];
            $NRSEQCORPEDIDO = $params['NRSEQCORPEDIDO'];
            $valida = $this->setorService->validaCor($NRINICIOCOR, $NRFINALCOR, $NRSEQCORPEDIDO);
            if (count($valida) != 0) {
                throw new \Exception($this->salesMessage->getMessage(31));
            }
                $NRSEQCORPEDIDO = $this->util->newCode('CORPEDIDO', '50');
                $this->setorService->criaCor($NRINICIOCOR, $NRFINALCOR, $IDPISCAPED, $NRCORPEDIDO, $NRSEQCORPEDIDO);
                $message = array('message' => $this->salesMessage->getMessage("criado"));

            $response->addDataSet(new DataSet('AdicionaCorRepo', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
    
    public function excluiCor(Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $this->setorService->excluiCor($params['NRSEQCORPEDIDO']);
            $message = array('message' => $this->salesMessage->getMessage("excluido"));
            $cores = $this->setorService->buscaCoresPedido();
            for ($cont = 0 ; $cont < count($cores); $cont++) {
                switch ($cores[$cont]['IDPISCAPED']) {
                    case 'S':
                        $cores[$cont]['DSPISCAPED'] = "Sim";
                        break;
                    case 'N':
                        $cores[$cont]['DSPISCAPED'] = "Não";
                        break;
                }
            }
            $response->addDataSet(new DataSet('BuscaCoresPedidoRepo', $cores));
            $response->addDataSet(new DataSet('ExcluiCorRepo', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    //Grupo Ocorrencia
    public function buscaGrupoOcorre(Filter $request, Response $response) {
        try {

            $grupos = $this->ocorrenciaService->buscaGrupoOcorre();
            $response->addDataSet(new DataSet('BuscaGrupoOcorreRepo', $grupos));

        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function editaGrupoOcorre(Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);

            $CDGRPOCOR = $params['CDGRPOCOR'];
            $DSGRPOCOR = $params['DSGRPOCOR'];
            $IDTIPGRP =  $params['IDTIPGRP'];
            if($IDTIPGRP == '#padrao'){
                $IDTIPGRP = '3';
            }
            if($CDGRPOCOR == 'cria'){
                $CDGRPOCOR = $this->util->newCode('GRUPOCOR', '2');
                $this->ocorrenciaService->criaGrupoOcorre($CDGRPOCOR, $DSGRPOCOR, $IDTIPGRP);
                $message = array('message' => $this->salesMessage->getMessage("criado"));
            }else{
                $this->ocorrenciaService->alteraGrupoOcorre($CDGRPOCOR, $DSGRPOCOR, $IDTIPGRP);
                $message = array('message' => $this->salesMessage->getMessage("alterado"));
            }
            $grupos = $this->ocorrenciaService->buscaGrupoOcorre();

            $response->addDataSet(new DataSet('BuscaGrupoOcorreRepo', $grupos));
            $response->addDataSet(new DataSet('EditaGrupoOcorreRepo', $message));

        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
    
    public function excluiGrupoOcorre(Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $valida = $this->ocorrenciaService->buscaOcorrenciasGrupo($params['CDGRPOCOR']);;
            if(count($valida)!=0){
                throw new \Exception($this->salesMessage->getMessage(83));
            }
            $this->ocorrenciaService->excluiGrupoOcorre($params['CDGRPOCOR']);
            $message = array('message' => $this->salesMessage->getMessage("excluido"));
            $grupos = $this->ocorrenciaService->buscaGrupoOcorre();
            $response->addDataSet(new DataSet('BuscaGrupoOcorreRepo', $grupos));
            $response->addDataSet(new DataSet('ExcluiGrupoOcorreRepo', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
    
    //Ocorrencia
    public function buscaOcorrenciasGrupo (Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $ocorrencias = $this->ocorrenciaService->buscaOcorrenciasGrupo($params['CDGRPOCOR']);
            $response->addDataSet(new DataSet('BuscaOcorrenciasGrupoRepo', $ocorrencias));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function editaObservacao(Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $CDGRPOCOR  = $params['CDGRPOCOR'];
            $CDOCORR    = $params['CDOCORR'];
            $DSOCORR    = $params['DSOCORR'];
            $IDSINAL    = $params['IDSINAL'];
            $NRCORSINAL = $params['NRCORSINAL'];
            if($CDOCORR == 'cria'){
                $CDOCORR = $this->util->newCode('OCORRENCIA', '2');
                $this->ocorrenciaService->criaObservacao($CDGRPOCOR, $CDOCORR, $DSOCORR,$IDSINAL,$NRCORSINAL);
                $message = array('message' => $this->salesMessage->getMessage("criado"));
            }else{
                $this->ocorrenciaService->editaObservacao($CDGRPOCOR, $CDOCORR, $DSOCORR,$IDSINAL,$NRCORSINAL);
                $message = array('message' => $this->salesMessage->getMessage("alterado"));
            }
            $ocorrencias = $this->ocorrenciaService->buscaOcorrenciasGrupo($params['CDGRPOCOR']);
            $response->addDataSet(new DataSet('BuscaOcorrenciasGrupoRepo', $ocorrencias));
            $response->addDataSet(new DataSet('EditaObservacaoRepo', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function excluiObservacao(Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $valida = $this->ocorrenciaService->buscaProdutosOcorrencia($params['CDGRPOCOR'], $params['CDOCORR']);;
            if(count($valida)!= 0){
                throw new \Exception($this->salesMessage->getMessage(84));
            }
            $this->ocorrenciaService->excluiObservacao($params['CDGRPOCOR'],$params['CDOCORR']);
            $message = array('message' => $this->salesMessage->getMessage("excluido"));
            $ocorrencias = $this->ocorrenciaService->buscaOcorrenciasGrupo($params['CDGRPOCOR']);
            $response->addDataSet(new DataSet('BuscaOcorrenciasGrupoRepo', $ocorrencias));
            $response->addDataSet(new DataSet('ExcluiObservacaoRepo', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    //ProdutoOcorrencia
    public function buscaProdutosOcorrencia (Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $produtos = $this->ocorrenciaService->buscaProdutosOcorrencia($params['CDGRPOCOR'], $params['CDOCORR']);
            $response->addDataSet(new DataSet('BuscaProdutosOcorrenciaRepo', $produtos));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function editaProdutoOcorrencia(Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $CDGRPOCOR = $params['CDGRPOCOR'];
            $CDOCORR = $params['CDOCORR'];
            $CDPRODUTO = $params['CDPRODUTO'];
            $NRTEMPOPROD = $params['NRTEMPOPROD'];
            $CDPRODUTO = strchr($params['CDPRODUTO'],'#altera', true);//testa se é alteração e se for já pega o codigo do Produto
            if($CDPRODUTO == false){
                $CDPRODUTO = $params['CDPRODUTO'];
                $produto = $this->ocorrenciaService->buscaProdutoOcorrenciaEspecifico($CDGRPOCOR, $CDOCORR, $CDPRODUTO);
                if (count($produto) != 0) {
                    throw new \Exception($this->salesMessage->getMessage(85));
                } else {
                    $this->ocorrenciaService->criaProdutoOcorrencia($CDGRPOCOR, $CDOCORR, $CDPRODUTO, $NRTEMPOPROD);
                    $message = array('message' => $this->salesMessage->getMessage("criado"));
                }
            } else {
                $this->ocorrenciaService->editaProdutoOcorrencia($CDGRPOCOR, $CDOCORR, $CDPRODUTO, $NRTEMPOPROD);
                $message = array('message' => $this->salesMessage->getMessage("alterado"));
            }
            $produtos = $this->ocorrenciaService->buscaProdutosOcorrencia($params['CDGRPOCOR'], $params['CDOCORR']);
            $response->addDataSet(new DataSet('BuscaProdutosOcorrenciaRepo', $produtos));
            $response->addDataSet(new DataSet('EditaProdutoOcorrenciaRepo', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function excluiProdutoOcorrencia(Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $this->ocorrenciaService->excluiProdutoOcorrencia($params['CDGRPOCOR'], $params['CDOCORR'], $params['CDPRODUTO']);
            $message = array('message' => $this->salesMessage->getMessage("excluido"));
            $produtos = $this->ocorrenciaService->buscaProdutosOcorrencia($params['CDGRPOCOR'], $params['CDOCORR']);
            $response->addDataSet(new DataSet('BuscaProdutosOcorrenciaRepo', $produtos));
            $response->addDataSet(new DataSet('ExcluiProdutoOcorrenciaRepo', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
    
    //setorprodobs
    public function adicionaObservacaoProdutoSetor (Filter $request, Response $response){
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $CDPRODUTO = $params['CDPRODUTO'];
            $CDSETOR = $params['CDSETOR'];
            $CDGRPOCOR = $params['CDGRPOCOR'];
            $CDOCORR = $params['CDOCORR'];
            $NRTEMPOPROD = $params['NRTEMPOPROD'];
            if($NRTEMPOPROD == ''){
                $NRTEMPOPROD = null;
            }
            $validaNovo = $this->ocorrenciaService->validaObsevacao($CDPRODUTO, $CDSETOR, $CDGRPOCOR, $CDOCORR);
            if(count($validaNovo)!=0){
                throw new \Exception($this->salesMessage->getMessage(95));
            }
            $this->ocorrenciaService->adicionaObservacaoProdutoSetor($CDPRODUTO, $CDSETOR, $CDGRPOCOR, $CDOCORR, $NRTEMPOPROD);
            $message = array('message' => $this->salesMessage->getMessage("criado"));
            $ocorrencias = $this->ocorrenciaService->buscaObservacaoProdutoSetor($params['CDPRODUTO'], $params['CDSETOR'], $params['CDGRPOCOR'], $params['CDOCORR']);
            $response->addDataSet(new DataSet('AdicionaObservacaoProdutoSetorRepo', $ocorrencias));
            $response->addDataSet(new DataSet('ExcluiProdutoOcorrenciaRepo', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function buscaObservacaoProdutoSetor (Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $observacoes = $this->ocorrenciaService->buscaObservacaoProdutoSetor($params['CDPRODUTO'], $params['CDSETOR']);
            $response->addDataSet(new DataSet('BuscaObservacaoProdutoSetorRepo', $observacoes));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function buscaObservacaoProdutoSetorRow (Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $observacoes = $this->ocorrenciaService->buscaObservacaoProdutoSetorRow($params['CDPRODUTO'], $params['CDSETOR'], $params['CDOCORR']);
            $response->addDataSet(new DataSet('BuscaObservacaoProdutoSetorRowRepo', $observacoes));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function excluiObservacaoProdutoSetor (Filter $request, Response $response){
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $observacoes = json_decode($params['observacoes'], true);
            foreach ($observacoes as $observacao) {
                $this->ocorrenciaService->excluiObservacaoProdutoSetor($observacao['CDPRODUTO'], $observacao['CDSETOR'], $observacao['CDGRPOCOR'], $observacao['CDOCORR']);
            }
            $message = array('message' => $this->salesMessage->getMessage("excluido"));
            $response->addDataSet(new DataSet('ExcluiSetorFilial', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function buscaDetalhesObservacao (Filter $request, Response $response){
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $observacoes = $this->ocorrenciaService->buscaDetalhesObservacao($params['CDPRODUTO'], $params['CDSETOR'], $params['CDOCORR'], $params['CDGRPOCOR']);
            $response->addDataSet(new DataSet('BuscaDetalhesObservacaoRepo', $observacoes));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function alteraDetalhesObservacao (Filter $request, Response $response){
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $observacoes = $this->ocorrenciaService->alteraDetalhesObservacao($params['CDPRODUTO'], $params['CDSETOR'], $params['CDOCORR'], $params['CDGRPOCOR'], $params['NRTEMPOPROD']);
            $message = array('message' => $this->salesMessage->getMessage("alterado"));
            $response->addDataSet(new DataSet('AlteraDetalhesObservacaoRepo', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function importarProduto (Filter $request, Response $response){
        try {
            $params   = $request->getFilterCriteria()->getConditions();
            $params   = $this->util->getParams($params);
            $CDSETOR  = $params['CDSETOR'];
            $ECDSETOR = $params['ECDSETOR'];
            $produtos = $this->buscaProdutosSetorEspecifico($ECDSETOR);
                foreach ((array) $produtos as $prodAtual){
                    $NRTEMPOPROD = intval(substr($prodAtual['NRTEMPOPROD'],3,4)) + intval(substr($prodAtual['NRTEMPOPROD'],0,2))*60;
                    if(!empty($prodAtual['NRTEMPOEXIB'])){
                        $prodAtual['NRTEMPOEXIB'] = intval(substr($prodAtual['NRTEMPOEXIB'],3,4)) + intval(substr($prodAtual['NRTEMPOEXIB'],0,2))*60;
                    }
                    $this->setorService->criaProdutoSetor($CDSETOR, $prodAtual['CDPRODUTO'], $NRTEMPOPROD, $prodAtual['NRTEMPOEXIB']);
                    $obs =  $this->ocorrenciaService->buscaObservacaoProdutoSetor($prodAtual['CDPRODUTO'], $ECDSETOR);
                    foreach ($obs as $obsAtual) {
                        $this->ocorrenciaService->adicionaObservacaoProdutoSetor($prodAtual['CDPRODUTO'], $CDSETOR, $obsAtual['CDGRPOCOR'], $obsAtual['CDOCORR'], $obsAtual['NRTEMPOPROD']);
                    }
                    $intervalos = $this->setorService->buscaProdutoIntervalo($ECDSETOR, $prodAtual['CDPRODUTO']);
                    foreach ($intervalos as $intervAtual) {
                        $NRSEQINTERVALO = $this->util->newCode('SETORPRODINTER' . $CDSETOR . $intervAtual['CDPRODUTO'], '10');
                        $this->setorService->criaProdutoIntervalo($CDSETOR, $intervAtual['CDPRODUTO'], $NRSEQINTERVALO, $intervAtual['NRTEMPOINTER']);
                    }
                //$this->setorService->importarProduto($CDSETOR, $ECDSETOR);
                //$this->setorService->criaProdutoIntervalo($CDSETOR, $CDPRODUTO, $NRSEQINTERVALO, $NRTEMPOINTER);      
                }
            $message = array('message' => $this->salesMessage->getMessage("exportado"));
            $response->addDataSet(new DataSet('ImportarProdutoRepo', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));           
        }
    }

    public function importarSetor (Filter $request, Response $response){
        try {
            $params   = $request->getFilterCriteria()->getConditions();
            $params   = $this->util->getParams($params);
            $CDFILIAL = $params['NOVACDFILIAL'];
            $ECDFILIAL = $params['ECDFILIAL'];
            $CDSETOR  = $params['CDSETOR'];
            $setores = $this->setorService->buscaSetorFilialEspecifica($ECDFILIAL, $CDSETOR);
            $TEMPOBEEP = empty($setores[0]['TEMPOBEEP'])? null : $setores[0]['TEMPOBEEP'];
            $this->setorService->criaSetorFilial($CDSETOR, $CDFILIAL, $setores[0]['IDHABSOMKDS'],$setores[0]['IDHABROLLBKDS'], $setores[0]['IDHABTIMERPROD'],
                                                             $setores[0]['IDHABSOMPROD'], $setores[0]['IDHABCONTSOMPROD'], $setores[0]['IDBLOQPRODKDS'],
                                                             $setores[0]['NRROLLBTIME'], $setores[0]['IDCONTSOMKDS'], $setores[0]['IDHABPREENVIO'],
                                                             $TEMPOBEEP, $setores[0]['NRPRODATRAINISOM'], $setores[0]['IDSOMBEEP'], $setores[0]['IDCONCDIRETO']);
            $produtos = $this->buscaProdutosSetorEspecifico($CDSETOR);
            
            $message = array('message' => $this->salesMessage->getMessage("exportado"));
            $response->addDataSet(new DataSet('ImportarProdutoRepo', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));           
        }
    }

    public function buscaTeclas(Filter $request, Response $response) {
        try {
            $teclas = $this->setorService->buscaTeclas();
            $response->addDataSet(new DataSet('BuscaTeclasRepo', $teclas));

        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function buscaTecla(Filter $request, Response $response){
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $NRKEY  = $params['NRKEY'];

            $tecla = $this->setorService->buscaTecla($NRKEY);
            $response->addDataSet(new DataSet('BuscaTeclaRepo', $tecla));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function editaTecla (Filter $request, Response $response){
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $NRKEY  = $params['NRKEY'];
            $IDFUNCAO = $params['IDFUNCAO'];
            $IDKEY = $params['IDKEY'];

            $observacoes = $this->setorService->editaTecla($NRKEY, $IDFUNCAO, $IDKEY);
            $message = array('message' => $this->salesMessage->getMessage("alterado"));
            $response->addDataSet(new DataSet('EditaTeclaRepo', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function excluiTecla(Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $NRKEY = $params['NRKEY'];
            
            $this->setorService->excluiTecla($NRKEY);
            $message = array('message' => $this->salesMessage->getMessage("excluido"));
            $setores = $this->setorService->buscaTeclas();
            $response->addDataSet(new DataSet('ExcluiTeclaRepo', $message));
            $response->addDataSet(new DataSet('BuscaTeclasRepo', $setores));
        }catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function adicionaTecla (Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $IDFUNCAO = $params['IDFUNCAO'];
            $IDKEY = $params['IDKEY'];
            
            $NRKEY = $this->util->newCode('LAYOUTTECLAKDS', '10');
            $this->setorService->adicionaTecla($NRKEY, $IDFUNCAO, $IDKEY);

            $message = array('message' => $this->salesMessage->getMessage("criado"));
            $response->addDataSet(new DataSet('AdicionaTeclasRepo', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function adicionaSetorLoja (Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $params = $this->util->getParams($params);
            $CDFILIAL = $params['CDFILIAL'];
            $CDLOJA = $params['CDLOJA'];
            $CDSETOR = $params['CDSETOR'];
            
            $this->setorService->adicionaSetorLoja($CDFILIAL, $CDLOJA, $CDSETOR);

            $message = array('message' => $this->salesMessage->getMessage("criado"));
            $response->addDataSet(new DataSet('AdicionaSetorLojaRepo', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
}